<?php
$paypal_options = pm_appointment_book_paypal_settings();
$redirect_url = $paypal_options['redirect_url'];
$thankyou_url = $paypal_options['success'];
$currency = $paypal_options['currency'];

// # Create Payment using PayPal as payment method
// This sample code demonstrates how you can process a 
// PayPal Account based Payment.
// API used: /v1/payments/payment

use PayPal\Api\Amount;
use PayPal\Api\Details;
use PayPal\Api\Item;
use PayPal\Api\ItemList;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;

// ### Payer
// A resource representing a Payer that funds a payment
// For paypal account payments, set payment method
// to 'paypal'.
$payer = new Payer();
$payer->setPaymentMethod("paypal");

// ### Itemized information
// (Optional) Lets you specify item wise
// information


$price = (float) esc_html($session['booking_form_price']);
$qty = (int) esc_html($session['booking_form_price_qty']);
$shipping = 0.00;
$sub_total = $price*$qty;
$total = $sub_total + $shipping;

$product_name = esc_html(sprintf(__('Appointment Booking x%s', 'pm-appointment-book'), $qty));

$item1 = new Item();
$item1->setName($product_name)
    ->setCurrency($currency)
    ->setQuantity($qty)
    ->setSku("appointment-book") // Similar to `item_number` in Classic API
    ->setPrice($price);

$itemList = new ItemList();
$itemList->setItems(array($item1));

// ### Additional payment details
// Use this optional field to set additional
// payment information such as tax, shipping
// charges etc.
$details = new Details();
$details->setShipping($shipping)
    ->setSubtotal($sub_total);

// ### Amount
// Lets you specify a payment amount.
// You can also specify additional details
// such as shipping, tax.
$amount = new Amount();
$amount->setCurrency($currency)
    ->setTotal($total)
    ->setDetails($details);

// ### Transaction
// A transaction defines the contract of a
// payment - what is the payment for and who
// is fulfilling it. 
$transaction = new Transaction();
$transaction->setAmount($amount)
    ->setItemList($itemList)
    ->setDescription("PayPal Payment for Appointment Booking")
    ->setInvoiceNumber(uniqid());

// ### Redirect urls
// Set the urls that the buyer must be redirected to after 
// payment approval/ cancellation.
$redirectUrls = new RedirectUrls();
$redirectUrls->setReturnUrl($thankyou_url."?success=true")
    ->setCancelUrl($thankyou_url."success=false");

// ### Payment
// A Payment Resource; create one using
// the above types and intent set to 'sale'
$payment = new Payment();
$payment->setIntent("sale")
    ->setPayer($payer)
    ->setRedirectUrls($redirectUrls)
    ->setTransactions(array($transaction));


// For Sample Purposes Only.
$request = clone $payment;

// ### Create Payment
// Create a payment by calling the 'create' method
// passing it a valid apiContext.
// (See bootstrap.php for more on `ApiContext`)
// The return object contains the state and the
// url to which the buyer must be redirected to
// for payment approval
try {
    $payment->create($apiContext);
} catch (Exception $ex) {
    // NOTE: PLEASE DO NOT USE RESULTPRINTER CLASS IN YOUR ORIGINAL CODE. FOR SAMPLE ONLY
 	//ResultPrinter::printError("Created Payment Using PayPal. Please visit the URL to Approve.", "Payment", null, $request, $ex);
	$return_status = array(
		'status' => 'error',
		'message' => 'Paypal Error: ' . $ex->getMessage(),
		'link' => ''
	);
	return $return_status;
	exit(1);
}

// ### Get redirect url
// The API response provides the url that you must redirect
// the buyer to. Retrieve the url from the $payment->getApprovalLink()
// method
$return_status = array(
	'status' => 'success',
	'message' => 'Here is you paypal payment link',
	'link' => $payment->getApprovalLink()
);

return $return_status;

