<?php
/**
 * Add Calendar Content
 *
 * @uses is_single()
 */
add_filter( 'the_content', 'pm_appointment_book_content_calendar', 20 );
function pm_appointment_book_content_calendar( $content ) {
    if ( is_single() && is_singular('calendar') ):
		require_once __DIR__."/../libs/calendar/vendor/autoload.php";
		global $post;
		$price = (get_post_meta($post->ID,'_pmab_schedule_price', true) ? get_post_meta($post->ID,'_pmab_schedule_price', true) : 1);
		wp_enqueue_style( 'pm-ab-fe-appointment-book-style', PM_APPOINTMENT_BOOK_DIR.'modules/frontend/css/pm-appointment-book-fe.css', '', PM_APPOINTMENT_BOOK_VERSION, 'all' );
		wp_enqueue_script( 'pm-ab-fe-appointment-book-script', PM_APPOINTMENT_BOOK_DIR.'modules/frontend/js/pm-appointment-book-fe.js', array('jquery'), PM_APPOINTMENT_BOOK_VERSION, true );
		wp_localize_script( 'pm-ab-fe-appointment-book-script', 'myAjax', array( 
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'pid' => $post->ID,
			'price' => $price
		));
		
		$permalink = get_permalink($post->ID);
		$options = get_option(PM_APPOINTMENT_BOOK_SETTINGS_OPTION);
		$payment_method = pm_appointment_book_payment_methods();
		
		$selected_month = date('m');
		$selected_year = date('Y');
		
		if( isset($_GET['month']) && isset($_GET['year']) ) {
			$selected_month = (int) trim(esc_html($_GET['month']));
			$selected_year = (int) trim(esc_html($_GET['year']));
		}
		
		$calendar_control = pm_appointment_book_calendar_control($selected_month, $selected_year);
		$cprev_month = $permalink.$calendar_control['prev'];
		$cnext_month = $permalink.$calendar_control['next'];
		
		$week_starts = get_option('start_of_week');
		$option_days = pm_appointment_book_days();
		$option_days_reset = array_values($option_days);
		$factory = new CalendR\Calendar;
		$factory->setFirstWeekday($week_starts);
		$month = $factory->getMonth($selected_year, $selected_month);
		$count = 1;
		$max_days = 6; // Mon to Sun
		
		$holidays = pm_appointment_book_holidays_array();
		
		//Option Values 
		$symbol = ($options ? $options['general']['currency_symbol'] : '$');
		$currency = ($options ? $options['general']['currency'] : 'USD');
		$typageid = ($options ? $options['general']['thank_you_page'] : '');
		$typageurl = (!empty($typageid) ? get_permalink($typageid) : '#');
		$rvpageid = ($options ? $options['general']['review_page'] : '');
		$rvpageurl = (!empty($rvpageid) ? get_permalink($rvpageid) : '');
		/*
			* Minimum Booking Days
		*/

		$booking_days_minimun = ( isset($options['general']['booking_days_minimun']) ? $options['general']['booking_days_minimun'] : 0);
		$booking_days_max = ( isset($options['general']['booking_days_max']) ? $options['general']['booking_days_max'] : 365);

		/*
			Don't display Calendar if options are not configured
		*/
		
		if(!empty($options) && !isset($_POST['booking_form_send'])  ):
		$content .= "<section id='pmab_booking_wrapper'>";
		if( !isset($options['general']['anonymous_booking']) ) {
			$content .= "<p class='pmab_notice'>".esc_html(__('Seems like you are not logged-in. Creating an account lets you manage your bookings and you cancel them any time. ', 'pm-appointment-book')).
			sprintf(__('<a href="%s">Click here</a> to create one.', 'pm-appointment-book'), wp_registration_url()).
			"</p>";
		}
		$content .= "<h3>{$month} {$selected_year}</h3>";
		$content .= "
		<div class='pmab_calendar_control'>
			<a class='prev' href='{$cprev_month}'>".esc_html(__('Previous', 'pm-appointment-book'))."</a>
			<a class='next' href='{$cnext_month}'>".esc_html(__('Next', 'pm-appointment-book'))."</a>
			<div class='clear'></div>
		</div>
		";
		$content .= "<table class='pmab_calendar form-table' border='1'>";
			$content .= "<thead>";
				for($x = $week_starts; $x <= $max_days; $x++) {
					$content .= "<th>{$option_days_reset[$x]}</th>";
				}
				for($x = 0; $x < $week_starts; $x++) {
					$content .= "<th>{$option_days_reset[$x]}</th>";
				}
			$content .= "</thead>";
			$content .= "<tbody>";
			foreach ($month as $week):
			$content .= "<tr>";
				foreach ($week as $day):
					$class = (!$month->includes($day) ? 'out-of-month' : '');
					$class .= ($day->isCurrent() ? ' current_day' : '');
					if($month->includes($day)) {
						$dl = strtolower($day);
						$enabled = get_post_meta($post->ID, '_pmab_enable_schedule_'.$dl, true);
						$current_date = "{$selected_month}/{$count}/{$selected_year}";
						$unix_date = strtotime($current_date);
						$formatted_date = date('m/d/Y', $unix_date);
						$now_formated = date('m/d/Y', time());
						$now = strtotime($now_formated);
						
						$days_minimun = strtotime("+{$booking_days_minimun} day");
						$days_max = strtotime("+{$booking_days_max} day");
						
						if( !in_array((string) $formatted_date, $holidays) )  {
							$format = ($unix_date >= $now && $enabled && $days_minimun <= $unix_date && $days_max >= $unix_date ? "<a class='booking_btn' data-day='{$dl}' data-href='{$formatted_date}' href='#{$formatted_date}'>{$count}</a>" : "<span>{$count}</span>");
							$content .= "<td class='{$class}'>{$format}</td>";
						} else {
							$format = "style='color: blue; ' ";
							$content .= "<td {$format} class='holiday {$class}'>{$count}</td>";
						}
						$count ++;
					} else {
						$content .= "<td class='{$class}'>-</td>";
					}
				endforeach;
			$content .= "</tr>";
			endforeach;
			$content .= "</tbody>";
		$content .= "</table>";
		$content .= "<div id='pmab_preloader'>
		<div class='spinner'>
		  <div class='bounce1'></div>
		  <div class='bounce2'></div>
		  <div class='bounce3'></div>
		</div>
		<p>".esc_html(__('Loading available schedule.', 'pm-appointment-book'))."</p></div>";
		$content .= "<div id='pmab_create_booking'>";
		$content .= "
		<form class='booking_form' method='POST' action='{$rvpageurl}' >
			<p class='form_field_wrapper booking_form_value booking_form_date_wrapper'>".esc_html(__('Selected Date', 'pm-appointment-book')).": <span></span></p>
			<div class='form_field_wrapper hidden'>
				<label for='booking_form_date'>".esc_html(__('Date', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_date' id='booking_form_date' />
			</div>
			<div class='form_field_wrapper available_time'>
			</div>
			<div class='form_field_wrapper hidden'>
				<label for='booking_form_currency'>".esc_html(__('Currency', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_currency' id='booking_form_currency' value='{$currency}' />
			</div>
			<div class='form_field_wrapper hidden'>
				<label for='booking_form_price'>".esc_html(__('Price', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_price' id='booking_form_price' value='{$price}' />
			</div>
			<div class='form_field_wrapper hidden'>
				<label for='booking_form_price_qty'>".esc_html(__('Qty', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_price_qty' id='booking_form_price_qty' value='0' />
			</div>
			<div class='form_field_wrapper hidden'>
				<label for='booking_form_price_total'>".esc_html(__('Total', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_price_total' id='booking_form_price_total' value='0' />
			</div>
			<p class='form_field_wrapper booking_form_value booking_form_price_wrapper'>".esc_html(__('Price per appointment', 'pm-appointment-book')).": {$symbol}<span>{$price}</span></p>
			<p class='form_field_wrapper booking_form_value booking_form_price_total_wrapper'>".esc_html(__('Total Price', 'pm-appointment-book')).": {$symbol}<span>0.00</span></p>
			<div class='form_field_wrapper'>
				<label for='booking_form_name'>".esc_html(__('Name', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_name' id='booking_form_name' class='field_text' />
			</div>
			<div class='form_field_wrapper'>
				<label for='booking_form_email'>".esc_html(__('Email', 'pm-appointment-book')).":</label>
				<input type='email' name='booking_form_email' id='booking_form_email' class='field_text' />
			</div>
			<div class='form_field_wrapper'>
				<label for='booking_form_number'>".esc_html(__('Contact Number', 'pm-appointment-book')).":</label>
				<input type='text' name='booking_form_number' id='booking_form_number' class='field_text' />
			</div>
			<div class='form_field_wrapper'>
				<label for='booking_form_note'>".esc_html(__('Additional note', 'pm-appointment-book')).":</label>
				<textarea name='booking_form_note' id='booking_form_note' ></textarea>
			</div>";
		$content .= $payment_method['output'];
		$content .= "<div id='booking_form_checked_wrapper' class='form_field_wrapper'>
				<label for='booking_form_checked'> <input type='checkbox' name='booking_form_checked' id='booking_form_checked' class='field_text' /> ".esc_html(__('Yes I have double checked the appointment. proceed to checkout.', 'pm-appointment-book'))."</label>
			</div>";
		if($payment_method['count'] > 0) {
			$content .= "<input id='booking_form_send' type='submit' name='booking_form_send' value='".esc_html(__('Send', 'pm-appointment-book'))."' />";
		}		
		$content .= "</form>";
		$content .= "</div>";
		$content .= "</section>";		
		endif; // End Options not configured ENDIF
	endif;
    return $content;
}
?>